@@ -21,18 +21,28 @@ extern "C" {
     pub fn qwac_canvas_create() -> u32;
     pub fn qwac_canvas_resize(canvas: u32, width_px: u32, height_px: u32);
     pub fn qwac_canvas_clear(canvas: u32);
-    pub fn qwac_canvas_draw_rectangle(canvas: u32, x: i32, y: i32, width: i32, height: i32, r: u8, g: u8, b: u8, a: u8);
+    pub fn qwac_canvas_draw_rectangle(
+        canvas: u32,
+        x: f64,
+        y: f64,
+        width: f64,
+        height: f64,
+        r: u8,
+        g: u8,
+        b: u8,
+        a: u8,
+    );
     pub fn qwac_canvas_draw_texture(
         canvas: u32,
         texture: u32,
-        source_x: i32,
-        source_y: i32,
-        source_width: i32,
-        source_height: i32,
-        dest_x: i32,
-        dest_y: i32,
-        dest_width: i32,
-        dest_height: i32,
+        source_x: f64,
+        source_y: f64,
+        source_width: f64,
+        source_height: f64,
+        dest_x: f64,
+        dest_y: f64,
+        dest_width: f64,
+        dest_height: f64,
     );
 
     pub fn qwac_canvas_delete(canvas: u32);
@@ -43,8 +53,8 @@ extern "C" {
     pub fn qwac_audio_oscillator_square(audio_node: u32);
     pub fn qwac_audio_oscillator_sawtooth(audio_node: u32);
     pub fn qwac_audio_oscillator_triangle(audio_node: u32);
-    pub fn qwac_audio_oscillator_delay(audio_node: u32, seconds: f64);
-    pub fn qwac_audio_oscillator_length(audio_node: u32, seconds: f64);
+    pub fn qwac_audio_source_delay(audio_node: u32, seconds: f64);
+    pub fn qwac_audio_source_length(audio_node: u32, seconds: f64);
     pub fn qwac_audio_source_play(audio_node: u32);
     pub fn qwac_audio_source_stop(audio_node: u32);
     pub fn qwac_audio_gain() -> u32;
