@@ -8,20 +8,20 @@
 mod ffi;
 
 pub mod audio;
+pub mod canvas;
+pub mod data;
 pub mod event;
 pub mod texture;
-pub mod data;
-pub mod canvas;
 
 #[cfg(feature = "alloc")]
 pub extern crate alloc;
 
-#[derive(Default, Clone, Copy, Hash, Debug, Eq, PartialEq, Ord, PartialOrd)]
+#[derive(Default, Clone, Copy, Debug, PartialEq, PartialOrd)]
 pub struct Rectangle {
-    pub x: i32,
-    pub y: i32,
-    pub width: i32,
-    pub height: i32,
+    pub x: f64,
+    pub y: f64,
+    pub width: f64,
+    pub height: f64,
 }
 
 #[derive(Default, Clone, Copy, Hash, Debug, Eq, PartialEq, Ord, PartialOrd)]
